rule win_session_manager_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.session_manager."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.session_manager"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 4c89b848240000 4c89b850240000 4c89b858240000 4c89b860240000 4c89b868240000 4c89b870240000 }
            // n = 6, score = 100
            //   4c89b848240000       | dec                 eax
            //   4c89b850240000       | mov                 ecx, edi
            //   4c89b858240000       | test                ebx, ebx
            //   4c89b860240000       | dec                 esp
            //   4c89b868240000       | mov                 ecx, edi
            //   4c89b870240000       | mov                 edx, 1

        $sequence_1 = { 4c8d35fb2d0100 83e63f 488beb 48c1fd06 48c1e606 498b04ee }
            // n = 6, score = 100
            //   4c8d35fb2d0100       | dec                 eax
            //   83e63f               | sar                 eax, 6
            //   488beb               | dec                 eax
            //   48c1fd06             | lea                 edx, [0x13a39]
            //   48c1e606             | and                 ecx, 0x3f
            //   498b04ee             | dec                 eax

        $sequence_2 = { 4c89b838060000 4c89b840060000 4c89b848060000 4c89b850060000 4c89b858060000 4c89b860060000 4c89b868060000 }
            // n = 7, score = 100
            //   4c89b838060000       | dec                 esp
            //   4c89b840060000       | mov                 dword ptr [eax + 0x3f8], edi
            //   4c89b848060000       | dec                 esp
            //   4c89b850060000       | mov                 dword ptr [eax + 0x400], edi
            //   4c89b858060000       | dec                 esp
            //   4c89b860060000       | mov                 dword ptr [eax + 0x408], edi
            //   4c89b868060000       | dec                 esp

        $sequence_3 = { 4c89b8100b0000 4c89b8180b0000 4c89b8200b0000 4c89b8280b0000 4c89b8300b0000 4c89b8380b0000 }
            // n = 6, score = 100
            //   4c89b8100b0000       | dec                 esp
            //   4c89b8180b0000       | mov                 dword ptr [eax + 0x3f8], edi
            //   4c89b8200b0000       | jmp                 0x14e6
            //   4c89b8280b0000       | dec                 esp
            //   4c89b8300b0000       | mov                 dword ptr [eax + 0x4e0], edi
            //   4c89b8380b0000       | dec                 esp

        $sequence_4 = { 4c89b8c8180000 4c89b8d0180000 4c89b8d8180000 4c89b8e0180000 4c89b8e8180000 4c89b8f0180000 }
            // n = 6, score = 100
            //   4c89b8c8180000       | dec                 eax
            //   4c89b8d0180000       | add                 esp, 0x20
            //   4c89b8d8180000       | dec                 eax
            //   4c89b8e0180000       | lea                 ecx, [0x1386d]
            //   4c89b8e8180000       | dec                 eax
            //   4c89b8f0180000       | mov                 dword ptr [ebx], ecx

        $sequence_5 = { 4c89b890030000 4c89b898030000 4c89b8a0030000 4c89b8a8030000 4c89b8b0030000 4c89b8b8030000 4c89b8c0030000 }
            // n = 7, score = 100
            //   4c89b890030000       | mov                 dword ptr [eax + 0x20], edi
            //   4c89b898030000       | dec                 esp
            //   4c89b8a0030000       | mov                 dword ptr [eax + 0x28], edi
            //   4c89b8a8030000       | je                  0x7c
            //   4c89b8b0030000       | inc                 ecx
            //   4c89b8b8030000       | lea                 edx, [ecx + 3]
            //   4c89b8c0030000       | mov                 word ptr [ebx], dx

        $sequence_6 = { 4c89b820220000 4c89b828220000 4c89b830220000 4c89b838220000 4c89b840220000 4c89b848220000 4c89b850220000 }
            // n = 7, score = 100
            //   4c89b820220000       | dec                 esp
            //   4c89b828220000       | mov                 dword ptr [eax + 0x22f0], edi
            //   4c89b830220000       | dec                 esp
            //   4c89b838220000       | mov                 dword ptr [eax + 0x22f8], edi
            //   4c89b840220000       | dec                 esp
            //   4c89b848220000       | mov                 dword ptr [eax + 0x2300], edi
            //   4c89b850220000       | dec                 esp

        $sequence_7 = { ff15???????? 488d0df81b0200 ff15???????? 488d0d7b170200 ff15???????? }
            // n = 5, score = 100
            //   ff15????????         |                     
            //   488d0df81b0200       | dec                 esp
            //   ff15????????         |                     
            //   488d0d7b170200       | mov                 dword ptr [eax + 0x2250], edi
            //   ff15????????         |                     

        $sequence_8 = { 488d0dd7070000 e8???????? e8???????? 488d0d42070000 e8???????? }
            // n = 5, score = 100
            //   488d0dd7070000       | dec                 esp
            //   e8????????           |                     
            //   e8????????           |                     
            //   488d0d42070000       | mov                 dword ptr [eax + 0x1ed0], edi
            //   e8????????           |                     

        $sequence_9 = { 4533c9 458d4101 488d542450 488bcb ff90a8000000 }
            // n = 5, score = 100
            //   4533c9               | mov                 dword ptr [eax + 0x1498], edi
            //   458d4101             | dec                 esp
            //   488d542450           | mov                 dword ptr [eax + 0x14a0], edi
            //   488bcb               | dec                 esp
            //   ff90a8000000         | mov                 dword ptr [eax + 0x1588], edi

    condition:
        7 of them and filesize < 372736
}